Управление очередью (заказы)
Пред. | Глава 4. Программирование эфира | След.

## Управление очередью (заказы)

Любой слушатель может заказывать композиции, отправляя jabber-боту команду queue. Эта команда принимает в качестве параметра фрагмент имени исполнителя или заголовка композиции, ей идентификатор или список меток. Найденная композиция добавляется в конец очереди. При выборе следующей композиции для проигрывания очередь имеет максимальный приоритет; за ней следует виртуальный плейлист, затем остальные плейлисты.

Привелегированные пользователи могут добавлять композиции в любом количестве и в любое время. Обычные пользователи могут добавлять по одной композиции за раз, и к таким композициям в качестве подмотки добавляется случайная композиция с меткой "queue-jingle" (смысл этих ограничений в том, чтобы резвящийся слушатель был очевиден, чтобы его нельзя было принять за дефект программного обеспечения).

Рекомендуемый подход к заказу композиций таков: сначала нужно найти композицию командой find, затем добавить её в очередь по идентификатору командой queue.

Пред. | Наверх | След.
Ручное программирование | Начало | Подмотка